summaryrefslogtreecommitdiffstats
path: root/views/views_delegate.h
diff options
context:
space:
mode:
authordhollowa@chromium.org <dhollowa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-08-29 21:07:00 +0000
committerdhollowa@chromium.org <dhollowa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-08-29 21:07:00 +0000
commit25fbafb729b15b66a217cdb7e6e175a252cf1156 (patch)
tree3c99890fe752ed709fb72c947795ebfe564645cb /views/views_delegate.h
parent32dce8260a55e265c389ad7eb999de9cf4608ccf (diff)
downloadchromium_src-25fbafb729b15b66a217cdb7e6e175a252cf1156.zip
chromium_src-25fbafb729b15b66a217cdb7e6e175a252cf1156.tar.gz
chromium_src-25fbafb729b15b66a217cdb7e6e175a252cf1156.tar.bz2
Revert 98679 - Restoring a session should restore window minimization state on Windows
These changes enable save and restore of minimized window state on Windows. (Mac and Linux came prior). The window state is now saved whenever size-changed notifications fire (in addition to the original activation and close cases). BUG=43274 TEST=Manual. Launch Chrome on Windows, create two browser windows, minimize "a" window, quit. Relaunch, expect "a" to be minimized. Review URL: http://codereview.chromium.org/7748036 TBR=dhollowa@chromium.org Review URL: http://codereview.chromium.org/7790010 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@98699 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'views/views_delegate.h')
-rw-r--r--views/views_delegate.h22
1 files changed, 12 insertions, 10 deletions
diff --git a/views/views_delegate.h b/views/views_delegate.h
index 4b032c3..13baff0 100644
--- a/views/views_delegate.h
+++ b/views/views_delegate.h
@@ -12,7 +12,6 @@
#endif
#include "ui/base/accessibility/accessibility_types.h"
-#include "ui/base/ui_base_types.h"
#include "views/views_export.h"
namespace gfx {
@@ -47,19 +46,22 @@ class VIEWS_EXPORT ViewsDelegate {
// TODO(beng): perhaps this should be a Widget.
virtual View* GetDefaultParentView() = 0;
// Saves the position, size and "show" state for the window with the
// specified name.
virtual void SaveWindowPlacement(const Widget* widget,
const std::wstring& window_name,
const gfx::Rect& bounds,
- ui::WindowShowState show_state) = 0;
-
- // Retrieves the saved position and size and "show" state for the window with
- // the specified name.
- virtual bool GetSavedWindowPlacement(
- const std::wstring& window_name,
- gfx::Rect* bounds,
- ui::WindowShowState* show_state) const = 0;
+ bool maximized) = 0;
+
+ // Retrieves the saved position and size for the window with the specified
+ // name.
+ virtual bool GetSavedWindowBounds(const std::wstring& window_name,
+ gfx::Rect* bounds) const = 0;
+
+ // Retrieves the saved maximized state for the window with the specified
+ // name.
+ virtual bool GetSavedMaximizedState(const std::wstring& window_name,
+ bool* maximized) const = 0;
virtual void NotifyAccessibilityEvent(
views::View* view, ui::AccessibilityTypes::Event event_type) = 0;
@@ -47,19 +46,22 @@ class VIEWS_EXPORT ViewsDelegate {
// TODO(beng): perhaps this should be a Widget.
virtual View* GetDefaultParentView() = 0;
- // Saves the position, size and "show" state for the window with the
+ // Saves the position, size and maximized state for the window with the
// specified name.
virtual void SaveWindowPlacement(const Widget* widget,